@@ -18,7 +18,6 @@ from dagster import (
     DagsterInvalidDefinitionError,
     DagsterInvariantViolationError,
     DefaultScheduleStatus,
-    LegacyFreshnessPolicy,
     OpExecutionContext,
     RunConfig,
     ScheduleDefinition,
@@ -28,7 +27,7 @@ from dagster import (
     define_asset_job,
     get_dagster_logger,
 )
-from dagster._core.definitions.asset_spec import SYSTEM_METADATA_KEY_DAGSTER_TYPE
+from dagster._core.definitions.assets.definition.asset_spec import SYSTEM_METADATA_KEY_DAGSTER_TYPE
 from dagster._core.definitions.metadata import TableMetadataSet
 from dagster._core.errors import DagsterInvalidPropertyError
 from dagster._core.types.dagster_type import Nothing
@@ -36,13 +35,14 @@ from dagster._record import ImportFrom, record
 
 from dagster_dbt.dbt_project import DbtProject
 from dagster_dbt.metadata_set import DbtMetadataSet
-from dagster_dbt.utils import ASSET_RESOURCE_TYPES, dagster_name_fn, select_unique_ids_from_manifest
+from dagster_dbt.utils import ASSET_RESOURCE_TYPES, dagster_name_fn, select_unique_ids
 
 if TYPE_CHECKING:
     from dagster_dbt.dagster_dbt_translator import DagsterDbtTranslator, DbtManifestWrapper
 
 DAGSTER_DBT_MANIFEST_METADATA_KEY = "dagster_dbt/manifest"
 DAGSTER_DBT_TRANSLATOR_METADATA_KEY = "dagster_dbt/dagster_dbt_translator"
+DAGSTER_DBT_PROJECT_METADATA_KEY = "dagster_dbt/project"
 DAGSTER_DBT_SELECT_METADATA_KEY = "dagster_dbt/select"
 DAGSTER_DBT_EXCLUDE_METADATA_KEY = "dagster_dbt/exclude"
 DAGSTER_DBT_SELECTOR_METADATA_KEY = "dagster_dbt/selector"
@@ -93,7 +93,9 @@ def get_asset_key_for_model(dbt_assets: Sequence[AssetsDefinition], model_name:
     check.sequence_param(dbt_assets, "dbt_assets", of_type=AssetsDefinition)
     check.str_param(model_name, "model_name")
 
-    manifest, dagster_dbt_translator = get_manifest_and_translator_from_dbt_assets(dbt_assets)
+    manifest, dagster_dbt_translator, dbt_project = get_manifest_and_translator_from_dbt_assets(
+        dbt_assets
+    )
 
     matching_model_ids = [
         unique_id
@@ -107,7 +109,7 @@ def get_asset_key_for_model(dbt_assets: Sequence[AssetsDefinition], model_name:
     return dagster_dbt_translator.get_asset_spec(
         manifest,
         next(iter(matching_model_ids)),
-        None,
+        dbt_project,
     ).key
 
 
@@ -151,7 +153,9 @@ def get_asset_keys_by_output_name_for_source(
     check.sequence_param(dbt_assets, "dbt_assets", of_type=AssetsDefinition)
     check.str_param(source_name, "source_name")
 
-    manifest, dagster_dbt_translator = get_manifest_and_translator_from_dbt_assets(dbt_assets)
+    manifest, dagster_dbt_translator, dbt_project = get_manifest_and_translator_from_dbt_assets(
+        dbt_assets
+    )
 
     matching = {
         unique_id: value
@@ -163,7 +167,9 @@ def get_asset_keys_by_output_name_for_source(
         raise KeyError(f"Could not find a dbt source with name: {source_name}")
 
     return {
-        dagster_name_fn(value): dagster_dbt_translator.get_asset_spec(manifest, unique_id, None).key
+        dagster_name_fn(value): dagster_dbt_translator.get_asset_spec(
+            manifest, unique_id, dbt_project
+        ).key
         for unique_id, value in matching.items()
     }
 
@@ -265,7 +271,9 @@ def build_dbt_asset_selection(
             bar_plus_and_foo_and_downstream_selection = bar_plus_and_foo_selection.downstream()
 
     """
-    manifest, dagster_dbt_translator = get_manifest_and_translator_from_dbt_assets(dbt_assets)
+    manifest, dagster_dbt_translator, dbt_project = get_manifest_and_translator_from_dbt_assets(
+        dbt_assets
+    )
     [dbt_assets_definition] = dbt_assets
 
     dbt_assets_select = dbt_assets_definition.op.tags[DAGSTER_DBT_SELECT_METADATA_KEY]
@@ -284,12 +292,14 @@ def build_dbt_asset_selection(
         select=dbt_assets_select,
         exclude=dbt_assets_exclude,
         selector=dbt_assets_selector,
+        project=dbt_project,
     ) & DbtManifestAssetSelection.build(
         manifest=manifest,
         dagster_dbt_translator=dagster_dbt_translator,
         select=dbt_select,
         exclude=dbt_exclude or DBT_DEFAULT_EXCLUDE,
         selector=dbt_selector or DBT_DEFAULT_SELECTOR,
+        project=dbt_project,
     )
 
 
@@ -365,7 +375,7 @@ def build_schedule_from_dbt_selection(
 
 def get_manifest_and_translator_from_dbt_assets(
     dbt_assets: Sequence[AssetsDefinition],
-) -> tuple[Mapping[str, Any], "DagsterDbtTranslator"]:
+) -> tuple[Mapping[str, Any], "DagsterDbtTranslator", Optional[DbtProject]]:
     check.invariant(len(dbt_assets) == 1, "Exactly one dbt AssetsDefinition is required")
     dbt_assets_def = dbt_assets[0]
     metadata_by_key = dbt_assets_def.metadata_by_key or {}
@@ -374,6 +384,7 @@ def get_manifest_and_translator_from_dbt_assets(
     manifest_wrapper: Optional[DbtManifestWrapper] = first_metadata.get(
         DAGSTER_DBT_MANIFEST_METADATA_KEY
     )
+    project = first_metadata.get(DAGSTER_DBT_PROJECT_METADATA_KEY)
     if manifest_wrapper is None:
         raise DagsterInvariantViolationError(
             f"Expected to find dbt manifest metadata on asset {first_asset_key.to_user_string()},"
@@ -387,7 +398,7 @@ def get_manifest_and_translator_from_dbt_assets(
             " but did not. Did you pass in assets that weren't generated by @dbt_assets?"
         )
 
-    return manifest_wrapper.manifest, dagster_dbt_translator
+    return manifest_wrapper.manifest, dagster_dbt_translator, project
 
 
 def get_asset_keys_to_resource_props(
@@ -409,6 +420,7 @@ class DbtCliInvocationPartialParams:
     ]
     selection_args: Sequence[str]
     indirect_selection: Optional[str]
+    dbt_project: Optional[DbtProject]
 
 
 def get_updated_cli_invocation_params_for_context(
@@ -425,8 +437,11 @@ def get_updated_cli_invocation_params_for_context(
 
     selection_args: list[str] = []
     indirect_selection = os.getenv(DBT_INDIRECT_SELECTION_ENV, None)
+    dbt_project = None
     if context and assets_def is not None:
-        manifest, dagster_dbt_translator = get_manifest_and_translator_from_dbt_assets([assets_def])
+        manifest, dagster_dbt_translator, dbt_project = get_manifest_and_translator_from_dbt_assets(
+            [assets_def]
+        )
 
         selection_args, indirect_selection_override = get_subset_selection_for_context(
             context=context,
@@ -447,6 +462,7 @@ def get_updated_cli_invocation_params_for_context(
         dagster_dbt_translator=dagster_dbt_translator,
         selection_args=selection_args,
         indirect_selection=indirect_selection,
+        dbt_project=dbt_project,
     )
 
 
@@ -579,31 +595,14 @@ def default_owners_from_dbt_resource_props(
     if owners_config:
         return owners_config
 
-    owner: Optional[str] = (dbt_resource_props.get("group") or {}).get("owner", {}).get("email")
+    owner: Optional[Union[str, Sequence[str]]] = (
+        (dbt_resource_props.get("group") or {}).get("owner", {}).get("email")
+    )
 
     if not owner:
         return None
 
-    return [owner]
-
-
-def default_freshness_policy_fn(
-    dbt_resource_props: Mapping[str, Any],
-) -> Optional[LegacyFreshnessPolicy]:
-    dagster_metadata = dbt_resource_props.get("meta", {}).get("dagster", {})
-    freshness_policy_config = dagster_metadata.get("freshness_policy", {})
-
-    freshness_policy = (
-        LegacyFreshnessPolicy(
-            maximum_lag_minutes=float(freshness_policy_config["maximum_lag_minutes"]),
-            cron_schedule=freshness_policy_config.get("cron_schedule"),
-            cron_schedule_timezone=freshness_policy_config.get("cron_schedule_timezone"),
-        )
-        if freshness_policy_config
-        else None
-    )
-
-    return freshness_policy
+    return [owner] if isinstance(owner, str) else owner
 
 
 def default_auto_materialize_policy_fn(
@@ -624,7 +623,7 @@ def default_description_fn(dbt_resource_props: Mapping[str, Any], display_raw_sq
         dbt_resource_props.get("raw_sql") or dbt_resource_props.get("raw_code", ""), "    "
     )
     description_sections = [
-        dbt_resource_props["description"]
+        dbt_resource_props.get("description")
         or f"dbt {dbt_resource_props['resource_type']} {dbt_resource_props['name']}",
     ]
     if display_raw_sql:
@@ -740,6 +739,18 @@ def get_upstream_unique_ids(
     return upstreams
 
 
+def _build_child_map(manifest: Mapping[str, Any]) -> Mapping[str, AbstractSet[str]]:
+    """Manifests produced by early versions of dbt Fusion do not contain a child map, so we need to build it manually."""
+    if manifest.get("child_map"):
+        return manifest["child_map"]
+
+    child_map = defaultdict(set)
+    for unique_id, node in manifest["nodes"].items():
+        for upstream_unique_id in get_upstream_unique_ids(manifest, node):
+            child_map[upstream_unique_id].add(unique_id)
+    return child_map
+
+
 def build_dbt_specs(
     *,
     translator: "DagsterDbtTranslator",
@@ -750,16 +761,15 @@ def build_dbt_specs(
     io_manager_key: Optional[str],
     project: Optional[DbtProject],
 ) -> tuple[Sequence[AssetSpec], Sequence[AssetCheckSpec]]:
-    selected_unique_ids = select_unique_ids_from_manifest(
-        select=select,
-        exclude=exclude,
-        selector=selector,
-        manifest_json=manifest,
+    selected_unique_ids = select_unique_ids(
+        select=select, exclude=exclude, selector=selector, project=project, manifest_json=manifest
     )
 
     specs: list[AssetSpec] = []
     check_specs: dict[str, AssetCheckSpec] = {}
     key_by_unique_id: dict[str, AssetKey] = {}
+
+    child_map = _build_child_map(manifest)
     for unique_id in selected_unique_ids:
         resource_props = get_node(manifest, unique_id)
         resource_type = resource_props["resource_type"]
@@ -784,8 +794,8 @@ def build_dbt_specs(
         specs.append(spec)
 
         # add check specs associated with the asset
-        for child_unique_id in manifest["child_map"][unique_id]:
-            if not child_unique_id.startswith("test"):
+        for child_unique_id in child_map.get(unique_id, []):
+            if child_unique_id not in selected_unique_ids or not child_unique_id.startswith("test"):
                 continue
             check_spec = translator.get_asset_check_spec(
                 asset_spec=spec,
@@ -807,7 +817,7 @@ def build_dbt_specs(
                 upstream_id.startswith("source")
                 and translator.settings.enable_source_tests_as_checks
             ):
-                for child_unique_id in manifest["child_map"][upstream_id]:
+                for child_unique_id in child_map.get(upstream_id, []):
                     if not child_unique_id.startswith("test"):
                         continue
                     check_spec = translator.get_asset_check_spec(
